title 'MI and MIANALYZE example: Fitness data';

*-- Data with non-monotone pattern of missingness;
data FitMiss;
      input Oxygen RunTime RunPulse @@;
      datalines;
    44.609  11.37  178     45.313  10.07  185  
    54.297   8.65  156     59.571    .      .  
    49.874   9.22    .     44.811  11.63  176  
      .     11.95  176          .  10.85    .  
    39.442  13.08  174     60.055   8.63  170  
    50.541    .      .     37.388  14.03  186  
    44.754  11.12  176     47.273    .      .  
    51.855  10.33  166     49.156   8.95  180  
    40.836  10.95  168     46.672  10.00    .  
    46.774  10.25    .     50.388  10.08  168  
    39.407  12.63  174     46.080  11.17  156  
    45.441   9.63  164       .      8.92    .  
    45.118  11.08    .     39.203  12.88  168  
    45.790  10.47  186     50.545   9.93  148  
    48.673   9.40  186     47.920  11.50  170  
    47.467  10.50  170  
    ;

*-- Produce m=5 imputed data sets;
proc mi data=FitMiss out=outmi seed=37851;
	var Oxygen RunTime RunPulse;
	ods exclude MCMCInitEst;
	run;

*-- Print some of the output data set (OUTMI);
proc print data=outmi (obs=10);
	title2 'Imputed data set (partial)';
	run;
	
*-- Run regression model for each;
proc reg data=outmi outest=outreg covout noprint;
	model Oxygen = RunTime RunPulse;
	by _Imputation_;
	run;

*-- Print results;
proc print data=outreg(obs=8);
	id _Imputation_;
	by _Imputation_;
	var _Type_ _Name_
		Intercept RunTime RunPulse;
	title2 'Output from first two imputed data sets';
	run;

proc print data=outreg;
	id _Imputation_;
	var Intercept RunTime RunPulse;
	where (_Type_ = 'PARMS');
	title2 'Parameter estimates from imputed data sets';
	run;

*-- Combine the estimates;
proc mianalyze data=outreg;
	var Intercept Runtime RunPulse;
	title2 'Parameter estimates combined';
	run;
