title 'PSIDEX1: Brief look at the PSID';

*-- Make a working copy of the PSID data;
data psid;
   set psid.psid;
   run;

*-- See whats there;
proc contents data=psid;
   run;

proc means data=psid maxdec=3;
   var exp wks ed lwage;

*-- Graphical and numerical overview;
%datachk(data=psid, var=exp wks ed lwage);

*-- WKS has a strongly negatively skewed distribution;
%symbox(data=psid, var=wks, powers=3 4 5 6 7);

*-- Compare lwage for dichotomous variables;
%splot(data=psid, var=lwage, class=fem south);
run;

proc glm data=psid;
	class fem south;
	model lwage = fem | south | union;
	run;

*-- Examine means for pairs of Fem, South, Union;
%intplot(data=psid, response=lwage, class=Fem South Union);

*-- Relations between quantitative variables;
%lowess(data=psid, y=lwage, x=ed, hsym=1, interp=rl);
%lowess(data=psid, y=lwage, x=exp, hsym=1, interp=rl);

%scatmat(data=psid, var=lwage ed exp, interp=rl, 
	anno=lowess, hsym=1, symbols=+);

*-- Fit a model;
proc glm data=psid;
	class fem south union;
	model lwage = fem | south | union  t  ed exp fem*ed;
	output out=results r=resid p=predict;
run; 

*-- Fit this model with GENMOD, get influence plots;
%inflglim(data=psid, resp=lwage,
	class=fem south union,
	model= fem | south | union  t ed exp fem*ed,
	id=id, dist=normal, lsize=1, print=no);
